.. _http-clients:

************
HTTP clients
************

Mopidy added an :ref:`HTTP frontend <ext-http>` and an :ref:`HTTP API
<http-api>` in 0.10 which together provides the building blocks needed for
creating web clients for Mopidy with the help of a WebSocket and a JavaScript
library provided by Mopidy.

This page will list any Mopidy web clients using the HTTP frontend. If you've
created one, please notify us so we can include your client on this page.

See :ref:`http-api` for details on how to build your own web client.


woutervanwijk/Mopidy-Webclient
==============================

.. image:: /_static/woutervanwijk-mopidy-webclient.png
    :width: 382
    :height: 621

The first web client for Mopidy is still under development, but is already very
usable. It targets both desktop and mobile browsers.

The web client used for the `Pi Musicbox
<http://www.woutervanwijk.nl/pimusicbox/>`_ is also available for other users
of Mopidy. See https://github.com/woutervanwijk/Mopidy-WebClient for details.


Mopidy Lux
==========

.. image:: /_static/dz0ny-mopidy-lux.png
    :width: 1000
    :height: 645

New web client developed by Janez Troha. See
https://github.com/dz0ny/mopidy-lux for details.


JukePi
======

New web client developed by Meantime IT in the UK for their office jukebox. See
https://github.com/meantimeit/jukepi for details.


Other web clients
=================

For Mopidy web clients using Mopidy's MPD frontend instead of HTTP, see
:ref:`mpd-web-clients`.
